@@ -23,8 +23,10 @@
 
 #include "atk.h"
 #include "atkmarshal.h"
+#include "atk-enum-types.h"
+
+GPtrArray *extra_roles = NULL;
 
-/* New GObject properties registered by AtkObject */
 enum
 {
   PROP_0,  /* gobject convention */
@@ -521,9 +523,11 @@ atk_object_ref_relation_set (AtkObject *accessible)
 AtkRole
 atk_role_register (const gchar *name)
 {
-  /* TODO: associate name with new type */
-  static guint type = ATK_ROLE_LAST_DEFINED;
-  return (++type);
+  if (!extra_roles)
+    extra_roles = g_ptr_array_new ();
+
+  g_ptr_array_add (extra_roles, g_strdup (name));
+  return extra_roles->len + ATK_ROLE_LAST_DEFINED;
 }
 
 /**
@@ -553,6 +557,7 @@ atk_object_get_role (AtkObject *accessible)
  * @accessible: an #AtkObject
  *
  * Gets the layer of the accessible.
+ * DEPRECATED: use atk_component_get_layer instead!
  *
  * Returns: an #AtkLayer which is the layer of the accessible
  **/
@@ -576,6 +581,7 @@ atk_object_get_layer (AtkObject *accessible)
  *
  * Gets the zorder of the accessible. The value G_MININT will be returned 
  * if the layer of the accessible is not ATK_LAYER_MDI.
+ * DEPRECATED: use atk_component_get_mdi_zorder instead!
  *
  * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
  * which the component is shown in relation to other components in the same 
@@ -895,10 +901,12 @@ atk_object_real_get_property (GObject      *object,
       g_value_set_int (value, atk_object_get_role (accessible));
       break;
     case PROP_LAYER:
-      g_value_set_int (value, atk_object_get_role (accessible));
+      if (ATK_IS_COMPONENT (accessible))
+        g_value_set_int (value, atk_component_get_layer (ATK_COMPONENT (accessible)));
       break;
     case PROP_MDI_ZORDER:
-      g_value_set_int (value, atk_object_get_mdi_zorder (accessible));
+      if (ATK_IS_COMPONENT (accessible))
+        g_value_set_int (value, atk_component_get_mdi_zorder (ATK_COMPONENT (accessible)));
       break;
     case PROP_PARENT:
       g_value_set_object (value, atk_object_get_parent (accessible));
@@ -1047,6 +1055,29 @@ atk_object_real_remove_property_change_handler (AtkObject           *obj,
   g_signal_handler_disconnect (obj, handler_id);
 }
 
+/**
+ * atk_object_initialize:
+ * @accessible: a #AtkObject
+ * @data: a #gpointer which identifies the object for which the AtkObject was created.
+ *
+ * This function is called when implementing subclasses of #AtkObject.
+ * It does initialization required for the new object. It is intended
+ * that this function should called only in the ..._new() functions used
+ * to create an instance of a subclass of #AtkObject
+ **/
+void
+atk_object_initialize (AtkObject  *accessible,
+                       gpointer   data)
+{
+  AtkObjectClass *klass;
+
+  g_return_if_fail (ATK_IS_OBJECT (accessible));
+
+  klass = ATK_OBJECT_GET_CLASS (accessible);
+  if (klass->initialize)
+    klass->initialize (accessible, data);
+}
+
 /*
  * This function is a signal handler for notify signal which gets emitted
  * when a property changes value.
@@ -1068,3 +1099,96 @@ atk_object_notify (GObject     *obj,
                  g_quark_from_string (pspec->name),
                  &values, NULL);
 }
+
+/**
+ * atk_role_get_name:
+ * @role: The #AtkRole whose name is required
+ *
+ * Gets the description string describing the #Roleype @role.
+ *
+ * Returns: the string describing the AtkRole
+ */
+G_CONST_RETURN gchar*
+atk_role_get_name (AtkRole role)
+{
+  GTypeClass *type_class;
+  GEnumValue *value;
+  gchar *name = NULL;
+
+  type_class = g_type_class_ref (ATK_TYPE_ROLE);
+  g_return_val_if_fail (G_IS_ENUM_CLASS (type_class), NULL);
+
+  value = g_enum_get_value (G_ENUM_CLASS (type_class), role);
+
+  if (value)
+    {
+      name = value->value_nick;
+    }
+  else
+    {
+      if (extra_roles)
+        {
+          gint n = role;
+
+          n -= ATK_ROLE_LAST_DEFINED + 1;
+
+          if (n < extra_roles->len)
+            name = g_ptr_array_index (extra_roles, n);
+        }
+    }
+  g_type_class_unref (type_class);
+  return name;
+}
+
+/**
+ * atk_role_for_name:
+ * @name: a string which is the (non-localized) name of an ATK role.
+ *
+ * Get the #AtkRole type corresponding to a rolew name.
+ *
+ * Returns: the #AtkRole enumerated type corresponding to the specified
+name,
+ *          or #ATK_ROLE_INVALID if no matching role is found.
+ **/
+AtkRole
+atk_role_for_name (const gchar *name)
+{
+  GTypeClass *type_class;
+  GEnumValue *value;
+  AtkRole role = ATK_ROLE_INVALID;
+
+  g_return_val_if_fail (name, ATK_ROLE_INVALID);
+
+  type_class = g_type_class_ref (ATK_TYPE_ROLE);
+  g_return_val_if_fail (G_IS_ENUM_CLASS (type_class), ATK_ROLE_INVALID);
+
+  value = g_enum_get_value_by_nick (G_ENUM_CLASS (type_class), name);
+
+  if (value)
+    {
+      role = value->value;
+    }
+  else
+    {
+     gint i;
+
+      if (extra_roles)
+        {
+          for (i = 0; i < extra_roles->len; i++)
+            {
+              gchar *extra_role = (gchar *)g_ptr_array_index (extra_roles, i);
+
+              g_return_val_if_fail (extra_role, ATK_ROLE_INVALID);
+
+              if (strcmp (name, extra_role) == 0)
+                {
+                  role = i + 1 + ATK_ROLE_LAST_DEFINED;
+                  break;
+                }
+            }
+        }
+    }
+  g_type_class_unref (type_class);
+  
+  return role;
+}
